Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(471)

Unified Diff: ash/common/wm/lock_layout_manager.h

Issue 2699033002: Replace WmWindowObserver with aura::WindowObserver. (Closed)
Patch Set: Check for null images in ShelfWindowWatcher. Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ash/common/wm/dock/docked_window_layout_manager.cc ('k') | ash/common/wm/lock_layout_manager.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/common/wm/lock_layout_manager.h
diff --git a/ash/common/wm/lock_layout_manager.h b/ash/common/wm/lock_layout_manager.h
index ba571e226b77c8e192143afc820f151cfe526e13..9ba7473d390c750a1e76a340ea26da62b2701457 100644
--- a/ash/common/wm/lock_layout_manager.h
+++ b/ash/common/wm/lock_layout_manager.h
@@ -9,8 +9,8 @@
#include "ash/common/shell_observer.h"
#include "ash/common/wm/wm_snap_to_pixel_layout_manager.h"
#include "ash/common/wm/wm_types.h"
-#include "ash/common/wm_window_observer.h"
#include "base/macros.h"
+#include "ui/aura/window_observer.h"
#include "ui/gfx/geometry/rect.h"
#include "ui/keyboard/keyboard_controller.h"
#include "ui/keyboard/keyboard_controller_observer.h"
@@ -34,7 +34,7 @@ class WMEvent;
// with LockWindowState.
class ASH_EXPORT LockLayoutManager
: public wm::WmSnapToPixelLayoutManager,
- public WmWindowObserver,
+ public aura::WindowObserver,
public ShellObserver,
public keyboard::KeyboardControllerObserver {
public:
@@ -50,9 +50,9 @@ class ASH_EXPORT LockLayoutManager
void SetChildBounds(WmWindow* child,
const gfx::Rect& requested_bounds) override;
- // Overriden from WmWindowObserver:
- void OnWindowDestroying(WmWindow* window) override;
- void OnWindowBoundsChanged(WmWindow* window,
+ // Overriden from aura::WindowObserver:
+ void OnWindowDestroying(aura::Window* window) override;
+ void OnWindowBoundsChanged(aura::Window* window,
const gfx::Rect& old_bounds,
const gfx::Rect& new_bounds) override;
« no previous file with comments | « ash/common/wm/dock/docked_window_layout_manager.cc ('k') | ash/common/wm/lock_layout_manager.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698